.. _swh-py-template:

Software Heritage - Python module template
==========================================

Python module template, used as skeleton to create new modules.


.. toctree::
   :maxdepth: 2
   :caption: Contents:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
